@@ -50,8 +50,6 @@ class SmartqqClient:
         if "errmsg" in response_json:
             return self.stopped
         message = response_json["result"][0]["value"]
-        print(self.contact_manager.get_contact_info(message["from_uin"]))
-        print(message["content"][-1])
         return self.stopped
 
     def default_friend_message_handler(self, message):
